# Google Earth Engine Batch Asset Manager
Google Earth Engine Batch Asset Manager ambition is helping user with batch actions on assets. 

To learn how to use the program, please check [our documentation](https://tracek.github.io/gee_asset_manager/).

The program is open source and freely available, developed under Apache 2.0 licence. If you have any questions or feature requests, or perhaps would like to contribute, do visit [the GitHub page](https://github.com/tracek/gee_asset_manager).
